View source: R/register_extendr.R
| register_extendr | R Documentation |
This function is deprecated because we now rely on a small Rust binary to generate wrappers, which is called during the package build process.
register_extendr(path = ".", quiet = FALSE, force = FALSE, compile = NA)
path |
Path from which package root is looked up. |
quiet |
Logical indicating whether any progress messages should be generated or not. |
force |
Logical indicating whether to force regenerating
|
compile |
Logical indicating whether to recompile DLLs:
|
(Invisibly) Path to the file containing generated wrappers.
document()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.