| rust_source | R Documentation |
rust_source() compiles and loads a single Rust file for use in R.
rust_function() compiles and loads a single Rust function for use in R.
extendr_options() is a helper function to make it easier to pass additional
options when sourcing Rust code. It also proivdes defaults for each option
and does additional type checking.
rust_source(
file = NULL,
code = NULL,
env = parent.frame(),
echo = FALSE,
quiet = FALSE,
opts = NULL,
...
)
rust_function(
code,
extendr_fn_options = NULL,
env = parent.frame(),
echo = FALSE,
quiet = FALSE,
opts = NULL,
...
)
extendr_options(
cache_build = TRUE,
dependencies = NULL,
extendr_deps = NULL,
features = NULL,
generate_module_macro = TRUE,
module_name = "rextendr",
patch.crates_io = getOption("rextendr.patch.crates_io"),
profile = c("dev", "release", "perf"),
toolchain = getOption("rextendr.toolchain"),
use_dev_extendr = FALSE,
use_extendr_api = TRUE,
use_rtools = TRUE
)
## S3 method for class 'extendr_opts'
print(x, ...)
file |
character scalar, input rust file to source. |
code |
character scalar, input rust code to be used instead of |
env |
environment, the R environment in which the wrapping functions
will be defined. Default is |
echo |
logical scalar, whether to print standard output and errors of
|
quiet |
logical scalar, whether to print |
opts |
|
... |
user supplied extendr options to be injected into the
|
extendr_fn_options |
A list of extendr function options that are
inserted into the |
cache_build |
logical scalar, whether builds should be cached between
calls to |
dependencies |
character vector, dependencies to be added to |
extendr_deps |
named list, versions of |
features |
character vector, |
generate_module_macro |
logical scalar, whether the Rust module
macro should be automatically generated from the code. Default is |
module_name |
character scalar, name of the module defined in the Rust source via
|
patch.crates_io |
character vector, patch statements for crates.io to
be added to |
profile |
character scalar, Rust profile. Can be either |
toolchain |
character scalar, Rust toolchain. The default, |
use_dev_extendr |
logical scalar, whether to use development version of
|
use_extendr_api |
logical scalar, whether |
use_rtools |
logical scalar, whether to append the path to Rtools to the
|
x |
an |
For rust_source() and rust_function(), the result from
dyn.load(), which is an object of class DLLInfo. See getLoadedDLLs()
for more details. For extendr_options(), an extendr_opts list.
## Not run:
# creating a single rust function
rust_function("fn add(a:f64, b:f64) -> f64 { a + b }")
add(2.5, 4.7)
# creating multiple rust functions at once
code <- r"(
#[extendr]
fn hello() -> &'static str {
"Hello, world!"
}
#[extendr]
fn test( a: &str, b: i64) {
rprintln!("Data sent to Rust: {}, {}", a, b);
}
)"
rust_source(code = code)
hello()
test("a string", 42)
# use case with an external dependency: a function that converts
# markdown text to html, using the `pulldown_cmark` crate.
code <- r"(
use pulldown_cmark::{Parser, Options, html};
#[extendr]
fn md_to_html(input: &str) -> String {
let mut options = Options::empty();
options.insert(Options::ENABLE_TABLES);
let parser = Parser::new_ext(input, options);
let mut output = String::new();
html::push_html(&mut output, parser);
output
}
)"
rust_source(
code = code,
opts = extendr_options(
dependencies = list(`pulldown-cmark` = "0.8")
)
)
md_text <- "# The story of the fox
The quick brown fox **jumps over** the lazy dog.
The quick *brown fox* jumps over the lazy dog."
md_to_html(md_text)
# see default options
extendr_options()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.