View source: R/cran-compliance.R
| vendor_crates | R Documentation |
vendor_crates() is used to package the dependencies as required by CRAN.
It executes cargo vendor on your behalf creating a vendor/ directory and a
compressed vendor.tar.xz which will be shipped with package itself.
If you have modified your dependencies, you will need need to repackage
the vendored dependencies using vendor_crates().
vendor_pkgs() was renamed to vendor_crates().
vendor_crates(path = ".", quiet = FALSE, overwrite = NULL, clean = FALSE)
vendor_pkgs(path = ".", quiet = FALSE, overwrite = NULL, clean = FALSE)
path |
File path to the package for which to generate wrapper code. |
quiet |
Logical indicating whether any progress messages should be generated or not. |
overwrite |
Logical scalar or |
clean |
|
vendor_crates() returns a data.frame with two columns crate and version
## Not run:
vendor_crates()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.