write_license_note: Generate LICENSE.note file.

View source: R/license_note.R

write_license_noteR Documentation

Generate LICENSE.note file.

Description

[Experimental]

Usage

write_license_note(path = ".", quiet = FALSE, force = TRUE)

Arguments

path

character scalar, the R package directory

quiet

logical scalar, whether to signal successful writing of LICENSE.note (default is FALSE)

force

logical scalar, whether to regenerate LICENSE.note if LICENSE.note already exists (default is TRUE)

Details

LICENSE.note generated by this function contains information about all recursive dependencies in Rust crate.

The authors field in Cargo metadata is deprecated upstream (see https://github.com/rust-lang/cargo/issues/16458). This function relies on that field and may produce incomplete or missing author information as crates stop populating or removes the field entirely.

Value

text printed to LICENSE.note (invisibly).

Examples

## Not run: 
write_license_note()

## End(Not run)

rextendr documentation built on April 18, 2026, 5:07 p.m.