eng_extendr: Knitr engines
Description
Two knitr engines that enable code chunks of type extendr (individual Rust
statements to be evaluated via rust_eval()) and extendrsrc (Rust functions
or classes that will be exported to R via rust_source()).
Usage
eng_extendr(options)eng_extendrsrc(options)
Value
A character string representing the engine output.
Arguments
- options
A list of chunk options.