| write_license_note | R Documentation |
write_license_note(path = ".", quiet = FALSE, force = TRUE)
path |
character scalar, the R package directory |
quiet |
logical scalar, whether to signal successful writing of
LICENSE.note (default is |
force |
logical scalar, whether to regenerate LICENSE.note if
LICENSE.note already exists (default is |
LICENSE.note generated by this function contains information about all recursive dependencies in Rust crate.
The authors field in Cargo metadata is deprecated upstream
(see https://github.com/rust-lang/cargo/issues/16458). This function
relies on that field and may produce incomplete or missing author
information as crates stop populating or removes the field entirely.
text printed to LICENSE.note (invisibly).
## Not run:
write_license_note()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.